# ndx-hed Extension for NWB

[**Neurodata Without Borders (NWB)**](https://www.nwb.org/) is a data standard for organizing neurophysiology data.
NWB is used extensively as the data representation for single cell and animal recordings as well as
human neuroimaging modalities such as IEEG. HED (Hierarchical Event Descriptors) is a system of
standardized vocabularies and supporting tools that allows fine-grained annotation of data.
HED annotations can now be used in NWB to provide a column of HED annotations for any NWB
dynamic table. 

The [**HED annotation in NWB**](https://www.hed-resources.org/en/latest/HedAnnotationInNWB.html)
user guide explains in more detail how to use this extension for HED.


## Installation

**Python:**
```bash
pip install -U ndx-hed
```

**Matlab:**  The Matlab extension is under development
